@@ -19,6 +19,7 @@
 /* Headers we may want to use. */
 #define STDC_HEADERS 1
 /* #undef _GNU_SOURCE */
+#define HAVE_ALIGNED_ALLOC 1
 /* #undef HAVE_ALLOCA_H */
 #define HAVE_ARPA_INET_H 1
 /* #undef HAVE_ASM_TERMBITS_H */
@@ -95,7 +96,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_UTIME_H 1
-/* #undef HAVE_VARARGS_H */
+#define HAVE_VARARGS_H 1
 /* #undef HAVE_SYS_UTIME_H */
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_SYS_PARAM_H 1
@@ -163,7 +164,6 @@
 #define HAVE_LRAND48 1
 #define HAVE_LOCALTIME_R 1
 #define HAVE_LSTAT 1
-/* #undef HAVE_MEMALIGN */
 /* #define HAVE_MLOCK 1 see Bug#54662 */
 #define HAVE_NL_LANGINFO 1
 #define HAVE_MADVISE 1
@@ -332,7 +332,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN 1 
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -393,8 +393,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "aarch64"
-#define DEFAULT_MACHINE "aarch64"
+#define MACHINE_TYPE "sparc64"
+#define DEFAULT_MACHINE "sparc64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -529,16 +529,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 8
+#define MYSQL_VERSION_PATCH 9
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.8"
+#define PACKAGE_STRING "MySQL Server 10.6.9"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.8"
-#define VERSION "10.6.8"
+#define PACKAGE_VERSION "10.6.9"
+#define VERSION "10.6.9"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
